geowatch.demo.metrics\_demo.generate\_demodata module
=====================================================

.. automodule:: geowatch.demo.metrics_demo.generate_demodata
   :members:
   :undoc-members:
   :show-inheritance:
